@@ -291,42 +291,58 @@ guint32
 eel_gdk_pixbuf_average_value (GdkPixbuf *pixbuf)
 {
 	guint64 a_total, r_total, g_total, b_total;
-	int row, column;
-	gboolean has_alpha;
-	int width, height;
+	guint row, column;
 	int row_stride;
 	const guchar *pixels, *p;
 	int r, g, b, a;
-	int dividend;
+	guint dividend;
+	guint width, height;
 
-	has_alpha = gdk_pixbuf_get_has_alpha (pixbuf);
 	width = gdk_pixbuf_get_width (pixbuf);
 	height = gdk_pixbuf_get_height (pixbuf);
 	row_stride = gdk_pixbuf_get_rowstride (pixbuf);
 	pixels = gdk_pixbuf_get_pixels (pixbuf);
-	
+
 	/* iterate through the pixbuf, counting up each component */
 	a_total = 0;
 	r_total = 0;
 	g_total = 0;
 	b_total = 0;
-	for (row = 0; row < height; row++) {
-		p = pixels + (row * row_stride);
-		for (column = 0; column < width; column++) {
-			r = *p++;
-			g = *p++;
-			b = *p++;
-			a = has_alpha ? *p++ : 0xFF;
 
-			a_total += a;
-			r_total += r * a;
-			g_total += g * a;
-			b_total += b * a;
+	if (gdk_pixbuf_get_has_alpha (pixbuf)) {
+		for (row = 0; row < height; row++) {
+			p = pixels + (row * row_stride);
+			for (column = 0; column < width; column++) {
+				r = *p++;
+				g = *p++;
+				b = *p++;
+				a = *p++;
+				
+				a_total += a;
+				r_total += r * a;
+				g_total += g * a;
+				b_total += b * a;
+			}
 		}
+		dividend = height * width * 0xFF;
+		a_total *= 0xFF;
+	} else {
+		for (row = 0; row < height; row++) {
+			p = pixels + (row * row_stride);
+			for (column = 0; column < width; column++) {
+				r = *p++;
+				g = *p++;
+				b = *p++;
+				
+				r_total += r;
+				g_total += g;
+				b_total += b;
+			}
+		}
+		dividend = height * width;
+		a_total = dividend * 0xFF;
 	}
 
-	a_total *= 0xFF;
-	dividend = height * width * 0xFF;
 	return ((a_total + dividend / 2) / dividend) << 24
 		| ((r_total + dividend / 2) / dividend) << 16
 		| ((g_total + dividend / 2) / dividend) << 8
@@ -1200,62 +1216,6 @@ eel_gdk_pixbuf_draw_to_drawable_tiled (const GdkPixbuf *pixbuf,
 			   &drawable_tile_data);
 }
 
-/**
- * eel_gdk_pixbuf_get_global_buffer:
- * @minimum_width: The minimum width for the requested buffer.
- * @minimum_height: The minimum height for the requested buffer.
- *
- * Return value: A GdkPixbuf that is at least as big as the passed in 
- *               dimensions.
- *
- * Access a global buffer for temporary GdkPixbuf operations.  
- * The returned buffer will be at least as big as the passed in 
- * dimensions.  The contents are not guaranteed to be anything at
- * anytime.  Also, it is not thread safe at all. */
-
-static GdkPixbuf *global_buffer = NULL;
-
-static void
-destroy_global_buffer (void)
-{
-	if (global_buffer != NULL) {
-		g_object_unref (global_buffer);
-		global_buffer = NULL;
-	}
-}
-
-GdkPixbuf *
-eel_gdk_pixbuf_get_global_buffer (int minimum_width,
-				  int minimum_height)
-{
-	static gboolean at_exit_deallocator_installed = FALSE;
-
-	g_return_val_if_fail (minimum_width > 0, NULL);
-	g_return_val_if_fail (minimum_height > 0, NULL);
-
-	if (global_buffer != NULL) {
-		if (gdk_pixbuf_get_width (global_buffer) >= minimum_width
-		    && gdk_pixbuf_get_height (global_buffer) >= minimum_height) {
-			return global_buffer;
-		}
-
-		destroy_global_buffer ();
-	}
-
-	g_assert (global_buffer == NULL);
-
-	global_buffer = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 
-					minimum_width, minimum_height);
-
-
-	if (at_exit_deallocator_installed == FALSE) {
-		at_exit_deallocator_installed = TRUE;
-		eel_debug_call_at_shutdown (destroy_global_buffer);
-	}
-
-	return global_buffer;
-}
-
 /**
  * eel_gdk_pixbuf_intersect:
  * @pixbuf: A GdkPixbuf.
@@ -1697,3 +1657,4 @@ eel_self_check_gdk_pixbuf_extensions (void)
 }
 
 #endif /* !EEL_OMIT_SELF_CHECK */
+
