@@ -31,10 +31,11 @@
 #include "eel-type-builtins-evals.c"
 
 void
-eel_type_init(void)
+eel_type_init (void)
 {
 	int i;
 	GtkType type_id;
+	static gboolean initialized = FALSE;
 	
 	static struct {
 		const gchar *type_name;
@@ -45,6 +46,11 @@ eel_type_init(void)
 	} builtin_info[EEL_TYPE_N_BUILTINS] = {
 #include "eel-type-builtins-ids.c"
 	};
+
+	if (initialized) {
+		return;
+	}
+	initialized = TRUE;
 	
 	for (i = 0; i < EEL_TYPE_N_BUILTINS; i++) {
 		type_id = G_TYPE_INVALID;
